@@ -18,7 +18,7 @@ pytest_plugins = ["pytester"]
 @pytest.fixture(autouse=True)
 def add_doctest_fixtures(
     request: pytest.FixtureRequest,
-    doctest_namespace: t.Dict[str, t.Any],
+    doctest_namespace: dict[str, t.Any],
 ) -> None:
     from _pytest.doctest import DoctestItem
 
