@@ -1,46 +1,23 @@
 import pathlib
+from typing import Literal, Optional, TypedDict, TypeVar, Union
 
 import pytest
 
-from libvcs import GitProject, MercurialProject, SubversionProject
+from libvcs import GitSync, HgSync, SvnSync
+from libvcs._internal.run import ProgressCallbackProtocol
 from libvcs._internal.shortcuts import create_project
-from libvcs.exc import InvalidPipURL, InvalidVCS
-from libvcs.shortcuts import create_project_from_pip_url
+from libvcs._internal.types import StrPath
+from libvcs.exc import InvalidVCS
 
 
-@pytest.mark.parametrize(
-    "repo_dict,repo_class,raises_exception",
-    [
-        ({"pip_url": "git+https://github.com/freebsd/freebsd.git"}, GitProject, False),
-        (
-            {"pip_url": "hg+https://bitbucket.org/birkenfeld/sphinx"},
-            MercurialProject,
-            False,
-        ),
-        (
-            {"pip_url": "svn+http://svn.code.sf.net/p/docutils/code/trunk"},
-            SubversionProject,
-            False,
-        ),
-        (
-            {"pip_url": "sv+http://svn.code.sf.net/p/docutils/code/trunk"},
-            None,
-            InvalidPipURL,
-        ),
-    ],
-)
-def test_create_project_from_pip_url(
-    tmp_path: pathlib.Path, repo_dict, repo_class, raises_exception
-):
-    # add parent_dir via fixture
-    repo_dict["dir"] = tmp_path / "repo_name"
+class CreateProjectKwargsDict(TypedDict, total=False):
+    url: str
+    dir: StrPath
+    vcs: Literal["git"]
+    progress_callback: Optional[ProgressCallbackProtocol]
 
-    if raises_exception:
-        with pytest.raises(raises_exception):
-            create_project_from_pip_url(**repo_dict)
-    else:
-        repo = create_project_from_pip_url(**repo_dict)
-        assert isinstance(repo, repo_class)
+
+E = TypeVar("E", bound=BaseException)
 
 
 @pytest.mark.parametrize(
@@ -48,18 +25,18 @@ def test_create_project_from_pip_url(
     [
         (
             {"url": "https://github.com/freebsd/freebsd.git", "vcs": "git"},
-            GitProject,
-            False,
+            GitSync,
+            None,
         ),
         (
             {"url": "https://bitbucket.org/birkenfeld/sphinx", "vcs": "hg"},
-            MercurialProject,
-            False,
+            HgSync,
+            None,
         ),
         (
             {"url": "http://svn.code.sf.net/p/docutils/code/trunk", "vcs": "svn"},
-            SubversionProject,
-            False,
+            SvnSync,
+            None,
         ),
         (
             {"url": "http://svn.code.sf.net/p/docutils/code/trunk", "vcs": "svna"},
@@ -69,12 +46,15 @@ def test_create_project_from_pip_url(
     ],
 )
 def test_create_project(
-    tmp_path: pathlib.Path, repo_dict, repo_class, raises_exception
-):
+    tmp_path: pathlib.Path,
+    repo_dict: CreateProjectKwargsDict,
+    repo_class: type[Union[SvnSync, GitSync, HgSync]],
+    raises_exception: Union[None, Union[type[E], tuple[type[E], ...]]],
+) -> None:
     # add parent_dir via fixture
     repo_dict["dir"] = tmp_path / "repo_name"
 
-    if raises_exception:
+    if raises_exception is not None:
         with pytest.raises(raises_exception):
             create_project(**repo_dict)
     else:
